@@ -2,8 +2,8 @@
 
 __author__ = "Sebastian Thiel"
 __contact__ = "byronimo@gmail.com"
-__homepage__ = "https://github.com/Byron/smmap"
-version_info = (2, 0, 1)
+__homepage__ = "https://github.com/gitpython-developers/smmap"
+version_info = (4, 0, 0)
 __version__ = '.'.join(str(i) for i in version_info)
 
 # make everything available in root package for convenience
